@@ -1,5 +1,3 @@
-$:.unshift(File.dirname(__FILE__))
-
 # If this is a frozen gem in Rails 2.1 and RedCloth 3.x was already
 # loaded by Rails' ActionView::Helpers::TextHelper, the user will get
 # "redcloth_scan.bundle: Class is not a module (TypeError)"
@@ -7,7 +5,16 @@ $:.unshift(File.dirname(__FILE__))
 # appears to be fixed in Edge Rails [51e4106].
 Object.send(:remove_const, :RedCloth) if Object.const_defined?(:RedCloth) && RedCloth.is_a?(Class)
 
-require 'redcloth_scan'
+require 'rbconfig'
+begin
+  prefix = Config::CONFIG['arch'] =~ /mswin|mingw/ ? "#{Config::CONFIG['MAJOR']}.#{Config::CONFIG['MINOR']}/" : ''
+  lib = "#{prefix}redcloth_scan"
+  require lib
+rescue LoadError => e
+  e.message << %{\nCouldn't load #{lib}\nThe $LOAD_PATH was:\n#{$LOAD_PATH.join("\n")}}
+  raise e
+end
+
 require 'redcloth/version'
 require 'redcloth/textile_doc'
 require 'redcloth/formatters/base'
